summaryrefslogtreecommitdiffstats
path: root/external/include/glm/gtx/rotate_normalized_axis.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'external/include/glm/gtx/rotate_normalized_axis.hpp')
-rw-r--r--external/include/glm/gtx/rotate_normalized_axis.hpp50
1 files changed, 27 insertions, 23 deletions
diff --git a/external/include/glm/gtx/rotate_normalized_axis.hpp b/external/include/glm/gtx/rotate_normalized_axis.hpp
index f1dfa7b..3ac482c 100644
--- a/external/include/glm/gtx/rotate_normalized_axis.hpp
+++ b/external/include/glm/gtx/rotate_normalized_axis.hpp
@@ -8,9 +8,9 @@
/// @defgroup gtx_rotate_normalized_axis GLM_GTX_rotate_normalized_axis
/// @ingroup gtx
///
-/// @brief Quaternions and matrices rotations around normalized axis.
+/// Include <glm/gtx/rotate_normalized_axis.hpp> to use the features of this extension.
///
-/// <glm/gtx/rotate_normalized_axis.hpp> need to be included to use these functionalities.
+/// Quaternions and matrices rotations around normalized axis.
#pragma once
@@ -19,6 +19,10 @@
#include "../gtc/epsilon.hpp"
#include "../gtc/quaternion.hpp"
+#ifndef GLM_ENABLE_EXPERIMENTAL
+# error "GLM: GLM_GTX_rotate_normalized_axis is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it."
+#endif
+
#if GLM_MESSAGES == GLM_MESSAGES_ENABLED && !defined(GLM_EXT_INCLUDED)
# pragma message("GLM: GLM_GTX_rotate_normalized_axis extension included")
#endif
@@ -28,35 +32,35 @@ namespace glm
/// @addtogroup gtx_rotate_normalized_axis
/// @{
- /// Builds a rotation 4 * 4 matrix created from a normalized axis and an angle.
- ///
+ /// Builds a rotation 4 * 4 matrix created from a normalized axis and an angle.
+ ///
/// @param m Input matrix multiplied by this rotation matrix.
- /// @param angle Rotation angle expressed in radians if GLM_FORCE_RADIANS is define or degrees otherwise.
+ /// @param angle Rotation angle expressed in radians.
/// @param axis Rotation axis, must be normalized.
- /// @tparam T Value type used to build the matrix. Currently supported: half (not recommanded), float or double.
- ///
+ /// @tparam T Value type used to build the matrix. Currently supported: half (not recommended), float or double.
+ ///
/// @see gtx_rotate_normalized_axis
- /// @see - rotate(T angle, T x, T y, T z)
- /// @see - rotate(tmat4x4<T, P> const & m, T angle, T x, T y, T z)
- /// @see - rotate(T angle, tvec3<T, P> const & v)
- template <typename T, precision P>
- GLM_FUNC_DECL tmat4x4<T, P> rotateNormalizedAxis(
- tmat4x4<T, P> const & m,
- T const & angle,
- tvec3<T, P> const & axis);
+ /// @see - rotate(T angle, T x, T y, T z)
+ /// @see - rotate(mat<4, 4, T, Q> const& m, T angle, T x, T y, T z)
+ /// @see - rotate(T angle, vec<3, T, Q> const& v)
+ template<typename T, qualifier Q>
+ GLM_FUNC_DECL mat<4, 4, T, Q> rotateNormalizedAxis(
+ mat<4, 4, T, Q> const& m,
+ T const& angle,
+ vec<3, T, Q> const& axis);
/// Rotates a quaternion from a vector of 3 components normalized axis and an angle.
- ///
+ ///
/// @param q Source orientation
- /// @param angle Angle expressed in radians if GLM_FORCE_RADIANS is define or degrees otherwise.
+ /// @param angle Angle expressed in radians.
/// @param axis Normalized axis of the rotation, must be normalized.
- ///
+ ///
/// @see gtx_rotate_normalized_axis
- template <typename T, precision P>
- GLM_FUNC_DECL tquat<T, P> rotateNormalizedAxis(
- tquat<T, P> const & q,
- T const & angle,
- tvec3<T, P> const & axis);
+ template<typename T, qualifier Q>
+ GLM_FUNC_DECL tquat<T, Q> rotateNormalizedAxis(
+ tquat<T, Q> const& q,
+ T const& angle,
+ vec<3, T, Q> const& axis);
/// @}
}//namespace glm